.. _bugs:

Bugs!
=====

If you find a bug in the ASE software, please report it to the
developers so it can be fixed.  We need that feedback from the
community to maintain the quality of the code.

Bug report
----------

* If you are unsure if it is a real bug, or a usage problem, it is
  probably best to report the problem on the ``ase-users``
  mailing list (see :ref:`mailing_lists`).

  Please provide the failing script as well as the information about your
  environment (processor architecture, versions of python and numpy).
  Then we (or other users) can help you to find out if it is a bug.

  Another advantage of reporting bugs on the mailing list: often other
  users will tell you how to work around the bug (until it is solved).

* If you think it is a bug, you can also report it directly on our
  `bug tracking system`_.  The advantage of reporting bugs
  here is that it is not forgotten (which may be a risk on the mailing
  list).

We do not guarantee to fix all bugs, but we will do our best.


Known bugs
----------

A list of known bugs (tickets) is on our Trac_.

.. _bug tracking system: http://trac.fysik.dtu.dk/projects/ase/wiki/TracTickets
.. _Trac: http://trac.fysik.dtu.dk/projects/ase/report/1
